# If you don't want the tck20 to be built (depends jpox),
# give rpmbuild option '--without tck20'

%define with_tck20 %{!?_without_tck20:1}%{?_without_tck20:0}
%define without_tck20 %{?_without_tck20:1}%{!?_without_tck20:0}

%define section devel
%define ver1 1.1
%define ver2 2.0

Summary:        Apache JDO
Name:           apache-jdo
Version:        0.1
Release:        0.20050919.1jpp
Epoch:          0
License:        Apache Software License 2.0
URL:            http://wiki.apache.org/jdo/
Group:          Development/Libraries
Vendor:         JPackage Project
Distribution:   JPackage
Source0:        apache-jdo-20050919-src.tar.gz
Source1:        pom-maven2jpp-depcat.xsl
Source2:        pom-maven2jpp-newdepmap.xsl
Source3:        pom-maven2jpp-mapdeps.xsl
Source4:        apache-jdo-2.0-jpp-depmap.xml

Patch0:         apache-jdo-fostore20-project_properties.patch
Patch1:         apache-jdo-ri11-project_properties.patch

BuildRequires:  ant >= 0:1.6, ant-junit >= 0:1.6, jpackage-utils >= 0:1.6
BuildRequires:  junit
BuildRequires:  maven, saxon, saxon-scripts
BuildRequires:  antlr
BuildRequires:  bcel
BuildRequires:  c3p0
BuildRequires:  jakarta-commons-collections
BuildRequires:  jakarta-commons-dbcp
BuildRequires:  jakarta-commons-logging
BuildRequires:  jakarta-commons-pool
BuildRequires:  derby
BuildRequires:  geronimo-specs
BuildRequires:  log4j
BuildRequires:  spring-core
%if %{with_tck20}
BuildRequires:  jpox
%endif
Requires:  bcel
Requires:  c3p0
Requires:  jakarta-commons-collections
Requires:  jakarta-commons-dbcp
Requires:  jakarta-commons-logging
Requires:  jakarta-commons-pool
Requires:  derby
Requires:  geronimo-specs
Requires:  log4j

BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
Java Data Objects (JDO) is a standard way to access persistent 
data in databases, using plain old Java objects (POJO) to 
represent persistent data. The approach separates data 
manipulation (done by accessing Java data members in the Java 
domain objects) from database manipulation (done by calling 
the JDO interface methods). This separation of concerns leads 
to a high degree of independence of the Java view of data from 
the database view of the data. 
Interfaces are defined for the user's view of persistence: 
PersistenceManager: the component responsible for the life cycle 
of persistent instances, Query factory, and Transaction access 
Query: the component responsible for querying the datastore and 
returning persistent instances or values 
Transaction: the component responsible for initiating and 
completing transactions 
Commercial and open source implementations of JDO are available 
for relational databases, object databases, and file systems. 
JDO is being developed as a Java Specification Request in the 
Java Community Process. The original JDO 1.0 is JSR-12 and the 
current JDO 2.0 is JSR-243.


%package -n apache-jdo11
Summary:        Apache JDO 1.1
Group:          Development/Libraries

%description -n apache-jdo11
%{summary}.

%package -n apache-jdo11-javadoc
Summary:        Javadoc for Apache JDO 1.1
Group:          Development/Documentation

%description -n apache-jdo11-javadoc
%{summary}.

%package -n apache-jdo20
Summary:        Apache JDO 2.0
Group:          Development/Libraries

%description -n apache-jdo20
%{summary}.


%package -n apache-jdo20-javadoc
Summary:        Javadoc for Apache JDO 2.0
Group:          Development/Documentation

%description -n apache-jdo20-javadoc
%{summary}.

%prep
%setup -q -n %{name}
# remove all binary libs
for j in $(find . -name "*.jar"); do
	mv $j $j.no
done

%patch0 -b .sav
%patch1 -b .sav

%build
pushd trunk
%if %{without_tck20}
rm -rf tck20
%endif
export DEPCAT=$(pwd)/apache-jdo-2.0-depcat.new.xml
echo '<?xml version="1.0" standalone="yes"?>' > $DEPCAT
echo '<depset>' >> $DEPCAT
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    /usr/bin/saxon project.xml %{SOURCE1} >> $DEPCAT
    popd
done
echo >> $DEPCAT
echo '</depset>' >> $DEPCAT
/usr/bin/saxon $DEPCAT %{SOURCE2} > apache-jdo-2.0-depmap.new.xml
for p in $(find . -name project.xml); do
    pushd $(dirname $p)
    cp project.xml project.xml.orig
    /usr/bin/saxon -o project.xml project.xml.orig %{SOURCE3} map=%{SOURCE4}
    popd
done

for p in $(find . -name project.properties); do
    echo >> $p
    echo maven.repo.remote=file:/usr/share/maven-1.0/repository >> $p
    echo maven.home.local=$(pwd)/.maven >> $p
done

rm -rf .maven/repository/maven/jars
mkdir -p .maven/repository/maven/jars
build-jar-repository .maven/repository/maven/jars maven-jelly-tags

rm -rf .maven/repository/JPP/jars
mkdir -p .maven/repository/JPP/jars
build-jar-repository -s -p .maven/repository/JPP/jars \
antlr \
bcel \
c3p0 \
commons-collections \
commons-dbcp \
commons-logging \
commons-pool \
derby/derby \
derby/derbytools \
geronimo/spec-jta-1.0.1B \
junit \
log4j \
spring/core \


%if %{with_tck20}
build-jar-repository -s -p .maven/repository/JPP/jars \
jpox \
jpox-c3p0 \
jpox-dbcp \
jpox-enhancer \

%endif

export MAVEN_HOME_LOCAL=$(pwd)/.maven

maven \
        -Dmaven.repo.remote=file:/usr/share/maven-1.0/repository \
        -Dmaven.home.local=$MAVEN_HOME_LOCAL \
        -Dgoal=jar:install,javadoc,test:test multiproject:goal


%install
rm -rf $RPM_BUILD_ROOT

# jars
mkdir -p $RPM_BUILD_ROOT%{_javadir}/%{name}11
mkdir -p $RPM_BUILD_ROOT%{_javadir}/%{name}20

cp -p trunk/api11/target/jdo1-api-%{ver1}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}11/jdo1-api-%{version}.jar
cp -p trunk/api20/target/jdo2-api-%{ver2}-SNAPSHOT.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}20/jdo2-api-%{version}.jar
cp -p trunk/btree/target/jdo-btree-%{ver1}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}11/jdo-btree-%{version}.jar
cp -p trunk/core20/target/jdo2-core-%{ver2}-SNAPSHOT.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}20/jdo2-core-%{version}.jar
cp -p trunk/enhancer20/target/jdo2-enhancer-%{ver2}-SNAPSHOT.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}20/jdo2-enhancer-%{version}.jar
cp -p trunk/fostore20/target/jdo2-fostore-%{ver2}-SNAPSHOT.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}20/jdo2-fostore-%{version}.jar
cp -p trunk/query20/target/jdo2-query-%{ver2}-SNAPSHOT.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}20/jdo2-query-%{version}.jar
cp -p trunk/ri11/target/jdo1-ri-%{ver1}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}11/jdo1-ri-%{version}.jar
cp -p trunk/runtime20/target/jdo2-runtime-%{ver2}-SNAPSHOT.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}20/jdo2-runtime-%{version}.jar
cp -p trunk/tck11/target/jdo1-tck-%{ver1}.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}11/jdo1-tck-%{version}.jar
%if %{with_tck20}
cp -p trunk/tck20/target/jdo2-tck-%{ver2}-SNAPSHOT.jar \
  $RPM_BUILD_ROOT%{_javadir}/%{name}20/jdo2-tck-%{version}.jar
%endif


(cd $RPM_BUILD_ROOT%{_javadir}/%{name}11 && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)
(cd $RPM_BUILD_ROOT%{_javadir}/%{name}20 && for jar in *-%{version}.jar; do ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`; done)

# javadoc
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}11-%{version}/api11
cp -pr trunk/api11/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}11-%{version}/api11
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/api20
cp -pr trunk/api20/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/api20
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}11-%{version}/btree
cp -pr trunk/btree/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}11-%{version}/btree
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/core20
cp -pr trunk/core20/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/core20
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/enhancer20
cp -pr trunk/enhancer20/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/enhancer20
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/fostore20
cp -pr trunk/fostore20/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/fostore20
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/query20
cp -pr trunk/query20/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/query20
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}11-%{version}/ri11
cp -pr trunk/ri11/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}11-%{version}/ri11
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/runtime20
cp -pr trunk/runtime20/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/runtime20
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}11-%{version}/tck11
cp -pr trunk/tck11/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}11-%{version}/tck11
%if %{with_tck20}
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/tck20
cp -pr trunk/tck20/target/docs/apidocs/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}20-%{version}/tck20
%endif

ln -s %{name}11-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}11
ln -s %{name}20-%{version} $RPM_BUILD_ROOT%{_javadocdir}/%{name}20



# manual
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}11-%{version}
cp -p trunk/LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}11-%{version}
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}20-%{version}
cp -p trunk/LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}20-%{version}

%clean
rm -rf $RPM_BUILD_ROOT

%post -n apache-jdo11-javadoc
rm -f %{_javadocdir}/%{name}11
ln -s %{name}11-%{version} %{_javadocdir}/%{name}11

%postun -n apache-jdo11-javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}11
fi

%post -n apache-jdo20-javadoc
rm -f %{_javadocdir}/%{name}20
ln -s %{name}20-%{version} %{_javadocdir}/%{name}20

%postun -n apache-jdo20-javadoc
if [ "$1" = "0" ]; then
  rm -f %{_javadocdir}/%{name}20
fi

%files -n apache-jdo11
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}11-%{version}/LICENSE.txt
%{_javadir}/%{name}11

%files -n apache-jdo11-javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}11-%{version}
%ghost %{_javadocdir}/%{name}11

%files -n apache-jdo20
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}20-%{version}/LICENSE.txt
%{_javadir}/%{name}20

%files -n apache-jdo20-javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}20-%{version}
%ghost %{_javadocdir}/%{name}20

%changelog
* Mon Sep 19 2005 Ralph Apel <r.apel@r-apel.de> - 0:0.1-0.20050308.1jpp
- First JPackage build
